Package: rlist
Type: Package
Title: A Toolbox for Non-Tabular Data Manipulation
Version: 0.4.6.2
Author: Kun Ren <ken@renkun.me>
Maintainer: Kun Ren <ken@renkun.me>
Description: Provides a set of functions for data manipulation with
    list objects, including mapping, filtering, grouping, sorting,
    updating, searching, and other useful functions. Most functions
    are designed to be pipeline friendly so that data processing with
    lists can be chained.
Depends: R (>= 2.15)
Date: 2021-09-02
Suggests: testthat, stringdist
Imports: yaml, jsonlite, XML, data.table
License: MIT + file LICENSE
URL: https://renkun-ken.github.io/rlist/,
        https://github.com/renkun-ken/rlist,
        https://renkun-ken.github.io/rlist-tutorial/
BugReports: https://github.com/renkun-ken/rlist/issues
ByteCompile: TRUE
LazyData: true
RoxygenNote: 7.1.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2021-09-02 23:36:14 UTC; ken
Repository: CRAN
Date/Publication: 2021-09-03 12:20:02 UTC
Built: R 4.6.0; ; 2026-04-27 05:49:11 UTC; unix
