#' New York hourly weather data
#'
#' A non-tabular data of the hourly weather conditions of the New York City
#' from 2013-01-01 to 2013-03-01.
#'
#' Fetch date: 2014-11-23.
#'
#' Processed by rlist.
#'
#' To retrieve the data, please visit \url{http://openweathermap.org/api} for
#' API usage.
#' @format
#' See \url{http://openweathermap.org/weather-data#current}
"nyweather"
